.. highlight:: bash

To install the prerequisites for this example::

    pip install asphalt-web[django]

To start the example::

    PYTHONPATH=. asphalt run config.yaml

Then, navigate to http://localhost:8000 in your browser.
